"use strict";


var _chunkZKQDN4RBcjs = require('../../chunk-ZKQDN4RB.cjs');
require('../../chunk-IMCDDJAJ.cjs');

// src/common/crypto/aes-sealed.spec.ts
var _vitest = require('vitest');
_vitest.describe.call(void 0, "aes Encryption and Decryption", () => {
  let key;
  _vitest.beforeAll.call(void 0, async () => {
    key = await crypto.subtle.generateKey(
      {
        name: "AES-GCM",
        length: 256
      },
      true,
      ["encrypt", "decrypt"]
    );
  });
  _vitest.it.call(void 0, "should encrypt and decrypt data correctly", async () => {
    const data = new TextEncoder().encode("Hello, World!");
    const encryptedData = await _chunkZKQDN4RBcjs.hxEncrypt.call(void 0, data, key);
    const decryptedData = await _chunkZKQDN4RBcjs.hxDecrypt.call(void 0, encryptedData, key);
    _vitest.expect.call(void 0, new TextDecoder().decode(decryptedData)).toBe("Hello, World!");
  });
  _vitest.it.call(void 0, "should produce different ciphertexts for the same plaintext", async () => {
    const data = new TextEncoder().encode("Hello, World!");
    const encryptedData1 = await _chunkZKQDN4RBcjs.hxEncrypt.call(void 0, data, key);
    const encryptedData2 = await _chunkZKQDN4RBcjs.hxEncrypt.call(void 0, data, key);
    _vitest.expect.call(void 0, encryptedData1).not.toEqual(encryptedData2);
  });
  _vitest.it.call(void 0, "should fail to decrypt with a different key", async () => {
    const data = new TextEncoder().encode("Hello, World!");
    const encryptedData = await _chunkZKQDN4RBcjs.hxEncrypt.call(void 0, data, key);
    const differentKey = await crypto.subtle.generateKey(
      {
        name: "AES-GCM",
        length: 256
      },
      true,
      ["encrypt", "decrypt"]
    );
    await _vitest.expect.call(void 0, _chunkZKQDN4RBcjs.hxDecrypt.call(void 0, encryptedData, differentKey)).rejects.toThrow();
  });
});
//# sourceMappingURL=aes-sealed.spec.cjs.map