import {
  hxDecrypt,
  hxEncrypt
} from "../../chunk-WBCYR5DW.js";
import "../../chunk-I7BWSAN6.js";

// src/common/crypto/aes-sealed.spec.ts
import { beforeAll, describe, expect, it } from "vitest";
describe("aes Encryption and Decryption", () => {
  let key;
  beforeAll(async () => {
    key = await crypto.subtle.generateKey(
      {
        name: "AES-GCM",
        length: 256
      },
      true,
      ["encrypt", "decrypt"]
    );
  });
  it("should encrypt and decrypt data correctly", async () => {
    const data = new TextEncoder().encode("Hello, World!");
    const encryptedData = await hxEncrypt(data, key);
    const decryptedData = await hxDecrypt(encryptedData, key);
    expect(new TextDecoder().decode(decryptedData)).toBe("Hello, World!");
  });
  it("should produce different ciphertexts for the same plaintext", async () => {
    const data = new TextEncoder().encode("Hello, World!");
    const encryptedData1 = await hxEncrypt(data, key);
    const encryptedData2 = await hxEncrypt(data, key);
    expect(encryptedData1).not.toEqual(encryptedData2);
  });
  it("should fail to decrypt with a different key", async () => {
    const data = new TextEncoder().encode("Hello, World!");
    const encryptedData = await hxEncrypt(data, key);
    const differentKey = await crypto.subtle.generateKey(
      {
        name: "AES-GCM",
        length: 256
      },
      true,
      ["encrypt", "decrypt"]
    );
    await expect(hxDecrypt(encryptedData, differentKey)).rejects.toThrow();
  });
});
//# sourceMappingURL=aes-sealed.spec.js.map